# -*- coding: utf-8 -*-
unicodes_en = __import__('en_emoji')


__all__ = [
    'EMOJI_UNICODE', 'UNICODE_EMOJI',
    'EMOJI_UNICODE_ENGLISH', 'UNICODE_EMOJI_ENGLISH',
    'EMOJI_ALIAS_UNICODE_ENGLISH', 'UNICODE_EMOJI_ALIAS_ENGLISH',
]


EMOJI_UNICODE = {
    'en': unicodes_en.EMOJI_UNICODE_ENGLISH,
}

UNICODE_EMOJI = {
    'en': unicodes_en.UNICODE_EMOJI_ENGLISH,
}



# -*- coding: utf-8 -*-

import re
from string import punctuation, digits
import itertools

emoji = __import__('emoji')

def lower(text):
    text=re.sub("İ","i",text)
    text = text.lower()
    return text

#TODO: translate emojis to turkish
def replace_emoji(text):
    return emoji.demojize(text, delimiters=(":", ":"))

def remove_emoji(text):
    emoji_pattern = re.compile("["
                               u"\U0001F600-\U0001F64F"  # emoticons
                               u"\U0001F300-\U0001F5FF"  # symbols & pictographs
                               u"\U0001F680-\U0001F6FF"  # transport & map symbols
                               u"\U0001F1E0-\U0001F1FF"  # flags (iOS)
                               u"\U00002500-\U00002BEF"  # chinese char
                               u"\U00002702-\U000027B0"
                               u"\U00002702-\U000027B0"
                               u"\U000024C2-\U0001F251"
                               u"\U0001f926-\U0001f937"
                               u"\U00010000-\U0010ffff"
                               u"\u2640-\u2642"
                               u"\u2600-\u2B55"
                               u"\u200d"
                               u"\u23cf"
                               u"\u23e9"
                               u"\u231a"
                               u"\ufe0f"  # dingbats
                               u"\u3030"
                               "]+", flags=re.UNICODE)
    return emoji_pattern.sub(r'', text)

def resubComma(text):
    return re.sub(","," ",text)

def vanish_punc(text):
    regex = re.compile('[%s]' % re.escape(punctuation))
    text = regex.sub(' ', text)
    return text

def replace_emoticon(word):
    check_pos = re.findall(r'(?::\)|:-\)|=\)|:D|:d|<3|\(:|:\'\)|\^\^|;\)|\(-:)', word)
    check_neg = re.findall(r'(:-\(|:\(|;\(|;-\(|=\(|:/|:\\|-_-|\):|\)-:)', word)
    if check_pos:
        #word = ":)"
        word = "SMILEYPOSITIVE"
    elif check_neg:
        #word = ":("
        word = "SMILEYNEGATIVE"
    return word

def remove_emoticon(text):
    new_text = re.sub(r'(?::\)|:-\)|=\)|:D|:d|<3|\(:|:\'\)|\^\^|;\)|\(-:)', '', text)
    new_text = re.sub(r'(:-\(|:\(|;\(|;-\(|=\(|:/|:\\|-_-|\):|\)-:)', '', new_text)
    return new_text

def remove_user_handle(text):
    return re.sub('@[^\s]+', '', text)

def remove_digits_and_extensions(text):
    return re.sub(r'[0-9][^\s]+', '', text)

def remove_digits(text):
    text = text.strip()
    vanish_digits = str.maketrans('', '', digits)
    text = text.translate(vanish_digits)
    return text

def remove_hashtag_and_word(text):
    return re.sub('#[^\s]+', '', text)

def remove_newline_char(text):
    return re.sub(' +', ' ', text.replace('\n', ' '))

def remove_extra_spaces(text):
    return re.sub(' +', ' ', text)

def dup_vanish(text):
     return (''.join(i for i, _ in itertools.groupby(text)))

def preprocess_sentence(sentence, stopwords):
    sentence = re.sub(r'https?:\/\/.*[\r\n]*', '', sentence)
    sentence = remove_user_handle(sentence)
    sentence = remove_hashtag_and_word(sentence)
    sentence = dup_vanish(sentence)
    sentence = remove_emoticon(sentence)
    sentence = remove_emoji(sentence)
    sentence = lower(sentence)
    sentence = resubComma(sentence)
    sentence = vanish_punc(sentence)
    sentence = remove_digits_and_extensions(sentence)
    sentence = remove_digits(sentence)
    sentence = remove_newline_char(sentence)

    sentence = remove_extra_spaces(sentence)
    # sentence = normalize(sentence)

    return sentence

# remove_emoji('iyi geceler 🙌')
# replace_emoji('iyi geceler 🙌')


import re
unicode_codes = __import__('unicode_codes')

_EMOJI_REGEXP = None
_DEFAULT_DELIMITER = ':'

def get_emoji_regexp(language='en'):

    """Returns compiled regular expression that matches emojis defined in
    ``emoji.UNICODE_EMOJI_ALIAS``. The regular expression is only compiled once.
    """

    global _EMOJI_REGEXP
    # Build emoji regexp once
    EMOJI_UNICODE = unicode_codes.EMOJI_UNICODE[language]
    if _EMOJI_REGEXP is None:
        # Sort emojis by length to make sure multi-character emojis are
        # matched first
        emojis = sorted(EMOJI_UNICODE.values(), key=len, reverse=True)
        pattern = u'(' + u'|'.join(re.escape(u) for u in emojis) + u')'
        _EMOJI_REGEXP = re.compile(pattern)
    return _EMOJI_REGEXP


def demojize(
        string,
        use_aliases=False,
        delimiters=(_DEFAULT_DELIMITER, _DEFAULT_DELIMITER),
        language='en',
):
    """Replace unicode emoji in a string with emoji shortcodes. Useful for storage.
    :param string: String contains unicode characters. MUST BE UNICODE.
    :param use_aliases: (optional) Return emoji aliases.  See ``emoji.UNICODE_EMOJI_ALIAS``.
    :param delimiters: (optional) User delimiters other than _DEFAULT_DELIMITER
    :param language: Choose language of emoji name
        >>> import emoji
        >>> print(emoji.emojize("Python is fun :thumbs_up:"))
        Python is fun 👍
        >>> print(emoji.demojize(u"Python is fun 👍"))
        Python is fun :thumbs_up:
        >>> print(emoji.demojize(u"Unicode is tricky 😯", delimiters=("__", "__")))
        Unicode is tricky __hushed_face__
    """
    UNICODE_EMOJI = unicode_codes.UNICODE_EMOJI[language]

    def replace(match):
        codes_dict = unicode_codes.UNICODE_EMOJI_ALIAS_ENGLISH if use_aliases else UNICODE_EMOJI
        val = codes_dict.get(match.group(0), match.group(0))
        # Val is the part we want to translate
        return delimiters[0] + val[1:-1] + delimiters[1]

    return re.sub(u'\ufe0f', '', (get_emoji_regexp(language).sub(replace, string)))